import { NormalizedOptions } from './internal-types';
export declare const IPC_TRANSPORT: string;
export declare function getNormalizedArgs(args: unknown[]): NormalizedOptions | null | undefined;
//# sourceMappingURL=utils.d.ts.map