export interface NormalizedOptions {
    host?: string;
    port?: number;
    path?: string;
}
export declare enum SocketEvent {
    CLOSE = "close",
    CONNECT = "connect",
    ERROR = "error",
    SECURE_CONNECT = "secureConnect"
}
//# sourceMappingURL=internal-types.d.ts.map